import Plugin from 'src/plugin-system/plugin.class';

export default class NotifyMe extends Plugin {
    init() {
        this.notifyButton = this.el;
        this.emailInput = document.getElementById('notify-me-email');
        this.submitButton = document.getElementById('submit-notify');

        this.registerEvents();
    }

    registerEvents() {
        if (this.notifyButton) {
            this.notifyButton.addEventListener('click', () => this.submitForm(true));
        }

        if (this.submitButton) {
            this.submitButton.addEventListener('click', () => this.submitForm(false));
        }
    }

    validateEmail(email) {
        const emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
        return emailRegex.test(email);
    }

    submitForm(isLoggedIn) {
        let email;
        const productId = this.notifyButton.dataset.productId;

        if (isLoggedIn) {
            email = this.notifyButton.dataset.customerEmail;
        } else {
            email = this.emailInput.value;
            if (!this.validateEmail(email)) {
                alert("Bitte geben Sie eine gültige E-Mail-Adresse ein.");
                return;
            }
        }

        fetch('/notification/subscribe', {
            method: 'POST',
            headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
            body: `email=${encodeURIComponent(email)}&productId=${encodeURIComponent(productId)}`
        })
            .then(response => response.json())
            .then(data => alert(data.message))
            .catch(error => console.error('Error:', error));
    }
}
